@@ -135,7 +135,7 @@ def parse_input(obj: Any) -> object:
     if isinstance(obj, GraphNode):
         return obj
 
-    if isinstance(obj, TaskRef):
+    if _is_dask_future(obj):
         return Alias(obj.key)
 
     if isinstance(obj, dict):
@@ -247,11 +247,11 @@ def convert_legacy_task(
                 return Task(key, _identity_cast, *parsed_args, typ=type(task))
             else:
                 return cast(_T, type(task)(parsed_args))
-    elif isinstance(task, TaskRef):
+    elif _is_dask_future(task):
         if key is None:
-            return Alias(task.key)
+            return Alias(task.key)  # type: ignore[attr-defined]
         else:
-            return Alias(key, target=task.key)
+            return Alias(key, target=task.key)  # type: ignore[attr-defined]
     else:
         return task
 
@@ -366,6 +366,15 @@ class TaskRef:
         return self
 
 
+def _is_dask_future(obj: object) -> bool:
+    """Check if obj is a dask Future (TaskRef or duck-typed with __dask_future__).
+
+    This supports both distributed.Future (which inherits from TaskRef) and
+    third-party scheduler futures that set __dask_future__ = True.
+    """
+    return isinstance(obj, TaskRef) or getattr(obj, "__dask_future__", False)
+
+
 class GraphNode:
     key: KeyType
     _dependencies: frozenset
@@ -609,8 +618,8 @@ class DataNode(GraphNode):
 
 
 def _get_dependencies(obj: object) -> set | frozenset:
-    if isinstance(obj, TaskRef):
-        return {obj.key}
+    if _is_dask_future(obj):
+        return obj.key  # type: ignore[attr-defined]
     elif isinstance(obj, GraphNode):
         return obj.dependencies
     elif isinstance(obj, dict):
