@@ -285,7 +285,8 @@ def test_np_dtype_of_delayed():
     # https://github.com/dask/dask/pull/4374#issuecomment-454381465
     np = pytest.importorskip("numpy")
     x = delayed(1)
-    with pytest.raises(TypeError):
+    with pytest.raises((ValueError, TypeError)):
+        # ValueError in numpy 2.4+, TypeError earlier.
         np.dtype(x)
     assert delayed(np.array([1], dtype="f8")).dtype.compute() == np.dtype("f8")
 
@@ -891,7 +892,7 @@ def test_annotations_survive_optimization():
     assert d.dask.layers["b"].annotations == {"foo": "bar"}
     optimized = collections_to_expr([d]).optimize()
     assert optimized.__dask_annotations__() == {
-        "foo": {k: "bar" for k in optimized.__dask_graph__()}
+        "foo": dict.fromkeys(optimized.__dask_graph__(), "bar")
     }
 
 
@@ -929,3 +930,35 @@ def test_delayed_fusion():
         result = dask.compute(obj2)
     assert len(dsk2) == 2
     assert dask.compute(obj) == result
+
+
+def test_p2p_as_delayed():
+    pytest.importorskip("distributed")
+    pytest.importorskip("numpy")
+    pytest.importorskip("dask.dataframe")
+    from distributed.utils_test import gen_cluster
+
+    import dask.dataframe as dd
+
+    @gen_cluster(client=True)
+    async def _test(c, s, *workers):
+        test_df = dd.from_dict(
+            {
+                "partition": [0, 1, 2, 3, 0, 1, 2, 3],
+                "value": [1, 2, 3, 4, 5, 6, 7, 8],
+            },
+            npartitions=2,
+        )
+        part_df = test_df.shuffle("partition", force=True, shuffle_method="p2p")
+
+        @delayed
+        def delayed_func(x):
+            return x
+
+        delay_df = delayed_func(part_df)
+        dd.utils.assert_eq(
+            await c.gather(c.compute(delay_df)),
+            await c.gather(c.compute(part_df)),
+        )
+
+    _test()
