@@ -464,7 +464,7 @@ def test_prefer_deep(abcde):
 
 
 def test_stacklimit(abcde):
-    dsk = {"x%s" % (i + 1): (inc, "x%s" % i) for i in range(10000)}
+    dsk = {"x%s" % (i + 1): (inc, f"x{i}") for i in range(10000)}
     dependencies, dependents = get_deps(dsk)
     ndependencies(dependencies, dependents)
 
@@ -2317,7 +2317,7 @@ def test_xarray_rechunk_map_reduce_cohorts(use_longest_path):
         # ensure that we run through longes path True and False
         keys = [("open-dataset", i, 0, 0) for i in range(20, 35)]
         dsk.update({("dummy", 0): (f, keys)})
-        dsk.update({k: (f,) for k in keys})
+        dsk.update(dict.fromkeys(keys, (f,)))
 
     o = order(dsk)
 
